


#ifndef __LIBYELP_TYPES_H__
#define __LIBYELP_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

#include "yelp-document.h"
#define YELP_TYPE_DOCUMENT_SIGNAL yelp_document_signal_get_type()
GType yelp_document_signal_get_type (void);
#include "yelp-view.h"
#define YELP_TYPE_VIEW_STATE yelp_view_state_get_type()
GType yelp_view_state_get_type (void);
G_END_DECLS

#endif /* __LIBYELP_TYPES_H__ */



